
#include <windows.h>  
#include "AdjWndRt.h" 


#if defined (WIN32)
	#define IS_WIN32 TRUE
#else
	#define IS_WIN32 FALSE
#endif

#define IS_NT      IS_WIN32 && (BOOL)(GetVersion() < 0x80000000)
#define IS_WIN32S  IS_WIN32 && (BOOL)(!(IS_NT) && (LOBYTE(LOWORD(GetVersion()))<4))
#define IS_WIN95   (BOOL)(!(IS_NT) && !(IS_WIN32S)) && IS_WIN32

HWND      hWnd = NULL; 
HINSTANCE hInst;   // current instance

LPCTSTR lpszAppName   = "MyApp";
LPCTSTR lpszClassName = "My Class";

BOOL InitAppInstance( HINSTANCE hInstance );
BOOL RegisterWin95( CONST WNDCLASS* lpwc );

int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance,
                      LPTSTR lpCmdLine, int nCmdShow)
{
    MSG  msg;
    RECT rect;

    // Check to see if there is previous version of the application
    // currently running. If not, then register the application class.
    //................................................................
    if ( !hPrevInstance && !InitAppInstance( hInstance ) )
        return FALSE;

    hInst = hInstance;

    // Initialize a RECT with the size and position of 
    // the client area we want.
    //...................................
    
    rect.left   = 100; // 100 pixels from the left of the screen.
    rect.top    = 150; // 150 pixels from the top of the screen.
    rect.right  = 200; // The width will be 100 pixels.
    rect.bottom = 200; // the height will be 50 pixels.

    AdjustWindowRect( &rect, WS_OVERLAPPEDWINDOW, TRUE );    
    
    hWnd = CreateWindow( lpszClassName,  // Class name registered.
                   "My Application",     // Title bar text.
                    WS_OVERLAPPEDWINDOW, // Window style.
                    rect.left,           // Use the rect calculated
                    rect.top,            //   with AdjustWindowRect()
                    rect.right,          //   for the size and
                    rect.bottom,         //   position.
                    NULL,                // No parent.
                    NULL,                // Use class menu.
                    hInstance,           
                    NULL);               

    if ( !hWnd )
       return( FALSE );

    ShowWindow( hWnd, nCmdShow ); 
    UpdateWindow( hWnd );         

    while ( GetMessage( &msg, NULL, 0, 0 ) )
    {
       TranslateMessage(&msg);
       DispatchMessage(&msg); 
    }
    
    return( TRUE );
}


BOOL InitAppInstance( HINSTANCE hInstance )
{
   WNDCLASS wc;

   // Register the main application window class.
   //............................................
   wc.style         = CS_HREDRAW | CS_VREDRAW;
   wc.lpfnWndProc   = (WNDPROC)WndProc;       
   wc.cbClsExtra    = 0;                      
   wc.cbWndExtra    = 0;                      
   wc.hInstance     = hInstance;              
   wc.hIcon         = LoadIcon( hInstance, lpszAppName ); 
   wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
   wc.hbrBackground = (HBRUSH)(COLOR_WINDOW+1);
   wc.lpszMenuName  = lpszAppName;              
   wc.lpszClassName = lpszClassName;              

   if ( IS_WIN95 )
   {
      if ( !RegisterWin95( &wc ) )
         return( FALSE );
   }
   else if ( !RegisterClass( &wc ) )
      return( FALSE );

   return( TRUE );
}


BOOL RegisterWin95( CONST WNDCLASS* lpwc )
{
   WNDCLASSEX wcex;

   wcex.style         = lpwc->style;
   wcex.lpfnWndProc   = lpwc->lpfnWndProc;
   wcex.cbClsExtra    = lpwc->cbClsExtra;
   wcex.cbWndExtra    = lpwc->cbWndExtra;
   wcex.hInstance     = lpwc->hInstance;
   wcex.hIcon         = lpwc->hIcon;
   wcex.hCursor       = lpwc->hCursor;
   wcex.hbrBackground = lpwc->hbrBackground;
   wcex.lpszMenuName  = lpwc->lpszMenuName;
   wcex.lpszClassName = lpwc->lpszClassName;

   // Added elements for Windows 95.
   //...............................
   wcex.cbSize = sizeof(WNDCLASSEX);
   wcex.hIconSm = LoadImage(wcex.hInstance, lpwc->lpszClassName, 
                            IMAGE_ICON, 16, 16,
                            LR_DEFAULTCOLOR );
			
   return RegisterClassEx( &wcex );
}

LRESULT CALLBACK WndProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
   switch( uMsg )
   {
      case WM_COMMAND :
              switch( LOWORD( wParam ) )
              {
                 case IDM_ABOUT :
                        DialogBox( hInst, "AboutBox", hWnd, (DLGPROC)About );
                        break;

                 case IDM_EXIT :
                        DestroyWindow( hWnd );
                        break;
              }
              break;
      
      case WM_DESTROY :
              PostQuitMessage(0);
              break;

      default :
            return( DefWindowProc( hWnd, uMsg, wParam, lParam ) );
   }

   return( 0L );
}


LRESULT CALLBACK About( HWND hDlg,           
                        UINT message,        
                        WPARAM wParam,       
                        LPARAM lParam)
{
   switch (message) 
   {
       case WM_INITDIALOG: 
               return (TRUE);

       case WM_COMMAND:                              
               if (   LOWORD(wParam) == IDOK         
                   || LOWORD(wParam) == IDCANCEL)    
               {
                       EndDialog(hDlg, TRUE);        
                       return (TRUE);
               }
               break;
   }

   return (FALSE); 
}
